
LLM Model Config
================


Configuration examples
----------------------

OpenAI
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

For OpenAI configuration, create .env files containing the API key

.. literalinclude:: ../sample_templates/llm/openai.yaml
   :language: yaml

llamacpp
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. literalinclude:: ../sample_templates/llm/llamacpp.yaml
   :language: yaml

Ollama + Litellm
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. literalinclude:: ../sample_templates/llm/litellm.yaml
   :language: yaml


Huggingface
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. literalinclude:: ../sample_templates/llm/huggingface.yaml
   :language: yaml


Reference
---------


.. automodule:: llmsearch.models.config
   :members:
   